===================
fastrlock changelog
===================

0.5 (2020-06-05)
================

* Rebuild with Cython 0.29.20 to support Py3.8 and later.


0.4 (2018-08-24)
================

* Rebuild with Cython 0.28.5.

* Linux wheels are faster through profile guided optimisation.

* Add missing file to sdist.
  (patch by Mark Harfouche, Github issue #5)


0.3 (2017-08-10)
================

* improve cimport support of C-API
  (patch by Naotoshi Seo, Github issue #3)

* provide ``fastrlock.__version__``


0.2 (2017-08-09)
================

* add missing readme file to sdist


0.1 (2017-06-04)
================

* initial release
